@@ -1,3 +1,22 @@
+# Copyright (c) 2022-2023 The pymovements Project Authors
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 """This module provides base dataset classes."""
 from __future__ import annotations
 
@@ -88,7 +107,7 @@ class Dataset:
         if self._filename_regex is not None:
             filename_regex = re.compile(self._filename_regex)
         else:
-            raise AttributeError("no regular expression for filenames is defined.")
+            raise AttributeError('no regular expression for filenames is defined.')
 
         # Get all filepaths that match regular expression.
         csv_filepaths = get_filepaths(
@@ -106,7 +125,7 @@ class Dataset:
             # This actually should never happen but mypy will complain otherwise.
             if match is None:
                 raise RuntimeError(
-                    f"file {filepath} did not match regular expression {self._filename_regex}",
+                    f'file {filepath} did not match regular expression {self._filename_regex}',
                 )
 
             # We use the groupdict of the match as a base and add the filepath.
@@ -141,10 +160,10 @@ class Dataset:
 
         if self.fileinfo is None:
             raise AttributeError(
-                "fileinfo was not read yet. please run read() or read_fileinfo() beforehand",
+                'fileinfo was not read yet. please run read() or read_fileinfo() beforehand',
             )
         if len(self.fileinfo) == 0:
-            raise AttributeError("no files present in fileinfo attribute")
+            raise AttributeError('no files present in fileinfo attribute')
 
         # read and preprocess input files
         for file_id, filepath in enumerate(tqdm(self.fileinfo['filepath'])):
@@ -186,10 +205,10 @@ class Dataset:
         """
         if self.gaze is None:
             raise AttributeError(
-                "gaze files were not read yet. please run read() or read_gaze_files() beforehand",
+                'gaze files were not read yet. please run read() or read_gaze_files() beforehand',
             )
         if len(self.gaze) == 0:
-            raise AttributeError("no files present in gaze attribute")
+            raise AttributeError('no files present in gaze attribute')
         if self.experiment is None:
             raise AttributeError('experiment must be specified for this method.')
 
@@ -234,10 +253,10 @@ class Dataset:
         """
         if self.gaze is None:
             raise AttributeError(
-                "gaze files were not read yet. please run read() or read_gaze_files() beforehand",
+                'gaze files were not read yet. please run read() or read_gaze_files() beforehand',
             )
         if len(self.gaze) == 0:
-            raise AttributeError("no files present in gaze attribute")
+            raise AttributeError('no files present in gaze attribute')
         if self.experiment is None:
             raise AttributeError('experiment must be specified for this method.')
 
@@ -287,7 +306,7 @@ class Dataset:
         >>> dataset.raw_dirpath  # doctest: +SKIP
         Path('data/CustomDataset/raw')
         """
-        return self.dirpath / "raw"
+        return self.dirpath / 'raw'
 
 
 class PublicDataset(Dataset, metaclass=ABCMeta):
@@ -296,6 +315,7 @@ class PublicDataset(Dataset, metaclass=ABCMeta):
     To implement this abstract base class for a new dataset, the attributes/properties `_mirrors`
     and `_resources` must be implemented.
     """
+
     def __init__(
         self,
         root: str,
@@ -342,7 +362,7 @@ class PublicDataset(Dataset, metaclass=ABCMeta):
                     success = True
 
                 except URLError as error:
-                    print(f"Failed to download (trying next):\n{error}")
+                    print(f'Failed to download (trying next):\n{error}')
                     # downloading the resource, try next mirror
                     continue
 
