@@ -22,20 +22,14 @@ This module holds all the main Event classes used for event detection.
 """
 from __future__ import annotations
 
+from pymovements.utils.decorators import auto_str
 
+
+@auto_str
 class Event:
     """
     Base Event class.
 
-    Parameters
-    ----------
-    name: str
-        Name of event.
-    onset: int
-        Starting index of event (included).
-    offset: int
-        Ending index of event (excluded).
-
     Attributes
     ----------
     name: str
@@ -47,6 +41,26 @@ class Event:
     """
 
     def __init__(self, name: str, onset: int, offset: int):
+        """
+        Parameters
+        ----------
+        name: str
+            Name of event.
+        onset: int
+            Starting index of event (included).
+        offset: int
+            Ending index of event (excluded).
+
+        Examples
+        --------
+        >>> event = Event(
+        ...    name="custom_event",
+        ...    onset=5,
+        ...    offset=10,
+        ... )
+        >>> print(event)
+        Event(name=custom_event, onset=5, offset=10)
+        """
         self.name = name
         self.onset = onset
         self.offset = offset
@@ -60,23 +74,25 @@ class Event:
         -------
         int
             duration in samples.
+
+        Examples
+        --------
+        >>> event = Event(
+        ...    name="custom_event",
+        ...    onset=5,
+        ...    offset=10,
+        ... )
+        >>> event.duration
+        5
         """
         return self.offset - self.onset
 
 
+@auto_str
 class Fixation(Event):
     """
     Fixation class.
 
-    Parameters
-    ----------
-    onset: int
-        Starting index of event (included).
-    offset: int
-        Ending index of event (excluded).
-    position: tuple[float, float]
-        (x, y) position of fixation
-
     Attributes
     ----------
     name: str
@@ -91,21 +107,35 @@ class Fixation(Event):
     _name = 'fixation'
 
     def __init__(self, onset: int, offset: int, position: tuple[float, float]):
+        """
+        Parameters
+        ----------
+        onset: int
+            Starting index of event (included).
+        offset: int
+            Ending index of event (excluded).
+        position: tuple[float, float]
+            (x, y) position of fixation
+
+        Examples
+        --------
+        >>> fixation = Fixation(
+        ...    onset=5,
+        ...    offset=10,
+        ...    position=(125.1, 852.3),
+        ... )
+        >>> print(fixation)
+        Fixation(name=fixation, onset=5, offset=10, position=(125.1, 852.3))
+        """
         super().__init__(name=self._name, onset=onset, offset=offset)
         self.position = position
 
 
+@auto_str
 class Saccade(Event):
     """
     Saccade class.
 
-    Parameters
-    ----------
-    onset: int
-        Starting index of event (included).
-    offset: int
-        Ending index of event (excluded).
-
     Attributes
     ----------
     name: str
@@ -118,4 +148,22 @@ class Saccade(Event):
     _name = 'saccade'
 
     def __init__(self, onset: int, offset: int):
+        """
+        Parameters
+        ----------
+        onset: int
+            Starting index of event (included).
+        offset: int
+            Ending index of event (excluded).
+
+        Examples
+        --------
+        >>> saccade = Saccade(
+        ...    onset=8,
+        ...    offset=10,
+        ... )
+        >>> print(saccade)
+        Saccade(name=saccade, onset=8, offset=10)
+        """
+
         super().__init__(name=self._name, onset=onset, offset=offset)
